CREATE TABLE areas (
  `id_area` INT(32) NOT NULL AUTO_INCREMENT,
  `title` TINYTEXT,
  `id_lng` INT,
  PRIMARY KEY(`id_area`)
);
|||
CREATE TABLE areas_items (
  `id_item` INT(32) NOT NULL AUTO_INCREMENT,
  `title` TINYTEXT,
  `pos` INT,
  `type` TINYTEXT,
  `id` INT,
  `id_area` INT,
  `id_lng` INT,
  PRIMARY KEY(`id_item`)
);
|||
CREATE TABLE `settings` (
  `id_set` int(32) NOT NULL auto_increment,
  `title` varchar(255) default NULL,
  `descr` mediumtext,
  `keywords` mediumtext,
  `id_page` int(11) default NULL,
  `id_menu` int(11) default NULL,
  `id_item` int(11) default NULL,
  `id_lng` int(11) default NULL,
  PRIMARY KEY  (`id_set`)
) ;
|||
CREATE TABLE pages (
  `id_page` INT(32) NOT NULL AUTO_INCREMENT,
  `text`  MEDIUMTEXT,
  `title` TINYTEXT,
  `id_cat` INT,
  `descr`  MEDIUMTEXT,
  `keywords`  MEDIUMTEXT,
  `last_upd` TIMESTAMP,
  `add_comments` ENUM('yes', 'no'),
  `id_lng` INT,
  PRIMARY KEY(`id_page`)
);
|||
CREATE TABLE pages_cat (
  `id_cat` INT(32) NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255),
  `id_lng` INT,
  PRIMARY KEY(`id_cat`)
);
|||
CREATE TABLE pages_comments (
  `id_comment` INT(32) NOT NULL AUTO_INCREMENT,
  `author` VARCHAR(255),
  `comment` MEDIUMTEXT,
  `visib` ENUM('yes', 'no'),
  `date` DATETIME,
  `id_page` INT,
  PRIMARY KEY(`id_comment`)
);
|||
CREATE TABLE menu (
  `id_menu`         INT(32) NOT NULL AUTO_INCREMENT,
  `title`           TINYTEXT,
  `disposition`     ENUM('vertical', 'horizontal'),
  `show_in_sitemap` ENUM('yes', 'no'),
  `pos`             INT,
  `main_tpl`        MEDIUMTEXT,
  `textitem_tpl`    MEDIUMTEXT,
  `imageitem_tpl`   MEDIUMTEXT,
  `id_lng`          INT,
  PRIMARY KEY(`id_menu`)
);
|||
CREATE TABLE menu_items (
  `id_item` INT(32) NOT NULL AUTO_INCREMENT,
  `caption` TINYTEXT,
  `bound_mod` VARCHAR(255),
  `param` VARCHAR(255),
  `pos` INT,
  `id_menu` INT,
  `id_item_prec` INT,
  `counter` INT,
  `img_act_name`  TINYTEXT,
  `img_pass_name` TINYTEXT,
  `img_width` INT DEFAULT 0,
  `img_height` INT DEFAULT 0,
  PRIMARY KEY(`id_item`)
);
|||
CREATE TABLE coltitles (
  `id_title` INT(32) NOT NULL AUTO_INCREMENT,
  `title` TINYTEXT,
  `tpl` MEDIUMTEXT,
  `id_lng` INT,
  PRIMARY KEY(`id_title`)
);
|||
CREATE TABLE images (
  `id_image` INT(32) NOT NULL AUTO_INCREMENT,
  `alt` TINYTEXT,
  `img_min_file` TINYTEXT,
  `img_max_file` TINYTEXT,
  `min_width` INT(4),
  `min_height` INT(4),
  `max_width` INT(4) DEFAULT 0,
  `max_height` INT(4) DEFAULT 0,
  `id_page` INT,
  PRIMARY KEY(`id_image`)
);
|||
CREATE TABLE counter (
  `id_visitor` INT(32) NOT NULL AUTO_INCREMENT,
  `ip` VARCHAR(255) NOT NULL,
  `time` DATETIME,
  `browser` ENUM('MSIE', 'Netscape', 'Opera', 'Firefox', 'none') NOT NULL DEFAULT 'none',
  `systems` ENUM('windows', 'unix', 'macintosh', 'robot_yandex', 'robot_google', 'robot_yandex', 'robot_aport', 'robot_msnbot', 'none') NOT NULL DEFAULT 'none',
  PRIMARY KEY(`id_visitor`)
);
|||
CREATE TABLE languages (
  `id_lng` int(32) NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255),
  `prefix` VARCHAR(10),
  `flag_img` VARCHAR(255),
  `flag_width` INT,
  `flag_height` INT,
  `pos` INT,
  `visibility` ENUM('visible', 'invisible'),
  `def` ENUM('yes', 'no'),
  `charset` VARCHAR(255),
  `rus_quotes` ENUM('yes', 'no'),
  PRIMARY KEY(`id_lng`)
);
|||
CREATE TABLE smiles (
  `id_smile` INT(32) NOT NULL AUTO_INCREMENT,
  `emotion`  TINYTEXT,
  `code`     TINYTEXT,
  `img_name` TINYTEXT,
  `width`    INT(4),
  `height`   INT(4),
  `pos`      INT(4),
  PRIMARY KEY(`id_smile`)
);
|||
CREATE TABLE groups (
  id_group INT NOT NULL AUTO_INCREMENT,
  names MEDIUMTEXT,
  PRIMARY KEY(id_group)
);
|||
CREATE TABLE users (
  id_user INT NOT NULL AUTO_INCREMENT,
  login TINYTEXT,
  psw TINYTEXT,
  name MEDIUMTEXT,
  email TINYTEXT,
  regdate DATETIME,
  lastvisit DATETIME,
  activated ENUM('yes', 'no'),
  id_lng INT,
  id_group INT,
  PRIMARY KEY(id_user)
);
|||
CREATE TABLE users_images (
  id_img INT NOT NULL AUTO_INCREMENT,
  avatar_ext TINYTEXT,
  avatar_width INT,
  avatar_height INT,
  photo_ext TINYTEXT,
  photo_width INT,
  photo_height INT,
  id_user INT,
  PRIMARY KEY(id_img)
);
|||
CREATE TABLE regform_fields (
  `id_field` INT(32) NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255),
  `type` VARCHAR(255),
  `caption` VARCHAR(255),
  `oblig` ENUM('yes', 'no'),
  `params` MEDIUMTEXT,
  `valtype` TINYTEXT,
  `pos` INT,
  `id_lng` INT,
  PRIMARY KEY (`id_field`)
);
|||
CREATE TABLE modules (
  `id_mod` INT(32) NOT NULL AUTO_INCREMENT,
  `name`  TINYTEXT,
  `names` MEDIUMTEXT,
  `descr` MEDIUMTEXT,
  `public_params` MEDIUMTEXT,
  `admin_params`  MEDIUMTEXT,
  `pos` INT,
  PRIMARY KEY (`id_mod`)
);